package com.wd.workoffice.util;

import android.content.ContentResolver;
import android.content.Context;
import android.database.Cursor;
import android.net.Uri;
import android.os.CountDownTimer;
import android.provider.MediaStore;
import android.text.TextUtils;
import android.widget.TextView;

import com.alibaba.fastjson.JSON;
import com.wd.workoffice.R;
import com.wd.workoffice.app.Config;
import com.wd.workoffice.app.WorkApp;
import com.wd.workoffice.bean.workEnum.OrderType;
import com.wd.workoffice.bean.workEnum.PermissionType;
import com.wd.workoffice.retrofit.RtfUtils;

import java.io.File;
import java.util.HashMap;
import java.util.Map;

import okhttp3.MediaType;
import okhttp3.RequestBody;

/**
 * author : flexible
 * email : lgd19940421@163.com
 * github: https://github.com/FlexibleXd
 **/
public class WorkUtils {

    /**
     * 将map数据转换为 普通的 json RequestBody
     *
     * @param map 以前的请求参数
     * @return
     */
    public static RequestBody convertMapToBody(Map<?, ?> map) {
        return RequestBody.create(MediaType.parse("application/json; charset=utf-8"), JSON.toJSONString(map));
    }

    public static Map<String, Object> simpleParam() {
        Map<String, Object> param = new HashMap<>();
        return param;
    }

    public static Map<String, Object> pageKey() {
        Map<String, Object> param = new HashMap<>();
        param.put("size", Config.SIZE);
        return param;
    }

    /**
     * code： SUPPLIER-供应商 CUSTOMER-客户 TRANSPORTERS-运输商
     *
     * @param code
     * @return
     */
    public static String getClientType(String code) {
        if (TextUtils.equals("SUPPLIER", code)) {
            return "供应商";
        } else if (TextUtils.equals("CUSTOMER", code)) {
            return "客户";
        } else {
            return "运输商";
        }
    }

    /**
     * code： 1：生产部门 2：销售部门 3：业务部门
     *
     * @param code
     * @return
     */
    public static String getDepType(Integer code) {
        String name = "";
        switch (code) {
            case 1:
                name = "生产部门";
                break;
            case 2:
                name = "销售部门";
                break;
            case 3:
                name = "业务部门";
                break;
        }
        return name;
    }

    /**
     * code： IN：厂内库 OUT：场外库
     *
     * @param code
     * @return
     */
    public static String getStockType(String code) {
        if (TextUtils.equals("IN", code)) {
            return "厂内库";
        } else if (TextUtils.equals("OUT", code)) {
            return "场外库";
        } else {
            return "场外库";
        }
    }

    /**
     * name：订单code
     *
     * @param name
     * @return
     */
    public static String getOrderCode(String name) {
        String code ="";
        for (OrderType value : OrderType.values()) {
            if (TextUtils.equals(value.getName(),name)){
                code=value.getCode();
            }
        }
        return code;
    }
    /**
     * name：订单code
     *
     * @param code
     * @return
     */
    public static String getOrderName(String code) {
        String name ="";
        for (OrderType value : OrderType.values()) {
            if (TextUtils.equals(value.getCode(),code)){
                name=value.getName();
            }
        }
        return name;
    }

    /**
     * name：流程code
     *
     * @param code
     * @return
     */
    public static String getPermissionName(String code) {
        String name ="";
        for (PermissionType value : PermissionType.values()) {
            if (TextUtils.equals(value.getCode(),code)){
                name=value.getName();
            }
        }
        return name;
    }

    /**
     * name：订单来源
     *：PDS-拆分生产订单 TRS-库存已有转单
     * @param code
     * @return
     */
    public static String getOrderFrom(String code) {
        String name ="";
        if(TextUtils.equals(code,"PDS")){
            name="拆分生产订单";
        }else if (TextUtils.equals(code,"TRS")){
            name="库存已有转单";
        }
        return name;
    }
    /**
     * 财务状态
     * 0未审核      1已通过      2不通过
     * @param code
     * @return
     */
    public static String getFinancialStatus(Integer code) {
        String name = "";
        switch (code) {
            case 0:
                name = "待审核";
                break;
            case 1:
                name = "已通过";
                break;
            case 2:
                name = "已驳回";
                break;
        }
        return name;
    }

    /**
     * 刷新token
     *
     * @return
     */
    public static void refreshToken() {
//        RtfUtils.getRtf().refreshToken()
    }

    public static File uriToFile(Uri uri, Context context) {
        String path = null;
        if ("file".equals(uri.getScheme())) {
            path = uri.getEncodedPath();
            if (path != null) {
                path = Uri.decode(path);
                ContentResolver cr = context.getContentResolver();
                StringBuffer buff = new StringBuffer();
                buff.append("(").append(MediaStore.Images.ImageColumns.DATA).append("=").append("'" + path + "'").append(")");
                Cursor cur = cr.query(MediaStore.Images.Media.EXTERNAL_CONTENT_URI, new String[]{MediaStore.Images.ImageColumns._ID, MediaStore.Images.ImageColumns.DATA}, buff.toString(), null, null);
                int index = 0;
                int dataIdx = 0;
                for (cur.moveToFirst(); !cur.isAfterLast(); cur.moveToNext()) {
                    index = cur.getColumnIndex(MediaStore.Images.ImageColumns._ID);
                    index = cur.getInt(index);
                    dataIdx = cur.getColumnIndex(MediaStore.Images.ImageColumns.DATA);
                    path = cur.getString(dataIdx);
                }
                cur.close();
                if (index == 0) {
                } else {
                    Uri u = Uri.parse("content://media/external/images/media/" + index);
                    System.out.println("temp uri is :" + u);
                }
            }
            if (path != null) {
                return new File(path);
            }
        } else if ("content".equals(uri.getScheme())) {
            // 4.2.2以后
            String[] proj = {MediaStore.Images.Media.DATA};
            Cursor cursor = context.getContentResolver().query(uri, proj, null, null, null);
            if (cursor.moveToFirst()) {
                int columnIndex = cursor.getColumnIndexOrThrow(MediaStore.Images.Media.DATA);
                path = cursor.getString(columnIndex);
            }
            cursor.close();

            return new File(path);
        } else {
            //Log.i(TAG, "Uri Scheme:" + uri.getScheme());
        }
        return null;
    }

    public static String replacePhone(String phone) {
        if (phone.length() > 7) {
            return phone.substring(0, 3) + " **** " + phone.substring(7, phone.length());
        } else if (phone.length() > 4) {
            return phone.substring(0, 3) + " ****";
        } else {
            return phone;
        }
    }

    /**
     * 倒计时
     *
     * @param txtTime
     * @param AllTime
     * @param JianGe
     */
    public static <T extends TextView> CountDownTimer timerSeckill(final T txtTime, long AllTime, final int JianGe, final int code) {
        if (code == 0) {
            txtTime.setClickable(false);
        }
        CountDownTimer timer = new CountDownTimer(AllTime, JianGe) {
            @Override
            public void onTick(long millisUntilFinished) {
                if (code == 0) {
                    txtTime.setText("( " + String.valueOf(millisUntilFinished / JianGe) + " )");
                    txtTime.setTextColor(WorkApp.getApp().getResources().getColor(R.color.flexible_text_gray));
                } else {
                    txtTime.setText("跳过  " + String.valueOf(millisUntilFinished / JianGe) + "s");
                }
            }

            @Override
            public void onFinish() {
                if (code == 0) {
                    txtTime.setText("重新获取");
                    txtTime.setClickable(true);
                    txtTime.setTextColor(WorkApp.getApp().getResources().getColor(R.color.mainColor));
                } else {
                    txtTime.setText("跳过  0s");
                }
            }
        };
        return timer.start();
    }
}
